@@ -55,9 +55,7 @@ def follow_reset_email_link(browser, email):
     link = re.search("http.+/", message).group(0)[:-1]
     browser.get(link)
 
-    from portal.tests.pageObjects.portal.password_reset_form_page import (
-        PasswordResetPage,
-    )
+    from portal.tests.pageObjects.portal.password_reset_form_page import PasswordResetPage
 
     return PasswordResetPage(browser)
 
@@ -96,8 +94,6 @@ def go_to_teacher_dashboard_page(browser):
 
 
 def go_to_independent_student_login_page(browser):
-    from portal.tests.pageObjects.portal.independent_login_page import (
-        IndependentStudentLoginPage,
-    )
+    from portal.tests.pageObjects.portal.independent_login_page import IndependentStudentLoginPage
 
     return IndependentStudentLoginPage(browser)
